@@ -1,7 +1,12 @@
 # ABSTRACT: The base class for all IO::Storm Spout.
 
 package IO::Storm::Spout;
-$IO::Storm::Spout::VERSION = '0.10';
+$IO::Storm::Spout::VERSION = '0.11';
+# Imports
+use strict;
+use warnings;
+use v5.14;
+
 use Moo;
 use namespace::clean;
 
@@ -90,7 +95,7 @@ IO::Storm::Spout - The base class for all IO::Storm Spout.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 NAME
 
